[
          {
            'unicode' => 'E63E',
            'name' => '晴れ',
            'sjis' => 'F89F',
            'en_name' => 'Fine'
          },
          {
            'unicode' => 'E63F',
            'name' => '曇り',
            'sjis' => 'F8A0',
            'en_name' => 'Cloudy'
          },
          {
            'unicode' => 'E640',
            'name' => '雨',
            'sjis' => 'F8A1',
            'en_name' => 'Rain'
          },
          {
            'unicode' => 'E641',
            'name' => '雪',
            'sjis' => 'F8A2',
            'en_name' => 'Snow'
          },
          {
            'unicode' => 'E642',
            'name' => '雷',
            'sjis' => 'F8A3',
            'en_name' => 'Thunder'
          },
          {
            'unicode' => 'E643',
            'name' => '台風',
            'sjis' => 'F8A4',
            'en_name' => 'Typhoon'
          },
          {
            'unicode' => 'E644',
            'name' => '霧',
            'sjis' => 'F8A5',
            'en_name' => 'Fog'
          },
          {
            'unicode' => 'E645',
            'name' => '小雨',
            'sjis' => 'F8A6',
            'en_name' => 'Drizzle'
          },
          {
            'unicode' => 'E646',
            'name' => '牡羊座',
            'sjis' => 'F8A7',
            'en_name' => 'Aries'
          },
          {
            'unicode' => 'E647',
            'name' => '牡牛座',
            'sjis' => 'F8A8',
            'en_name' => 'Taurus'
          },
          {
            'unicode' => 'E648',
            'name' => '双子座',
            'sjis' => 'F8A9',
            'en_name' => 'Gemini'
          },
          {
            'unicode' => 'E649',
            'name' => '蟹座',
            'sjis' => 'F8AA',
            'en_name' => 'Cancer'
          },
          {
            'unicode' => 'E64A',
            'name' => '獅子座',
            'sjis' => 'F8AB',
            'en_name' => 'Leo'
          },
          {
            'unicode' => 'E64B',
            'name' => '乙女座',
            'sjis' => 'F8AC',
            'en_name' => 'Virgo'
          },
          {
            'unicode' => 'E64C',
            'name' => '天秤座',
            'sjis' => 'F8AD',
            'en_name' => 'Libra'
          },
          {
            'unicode' => 'E64D',
            'name' => '蠍座',
            'sjis' => 'F8AE',
            'en_name' => 'Scorpio'
          },
          {
            'unicode' => 'E64E',
            'name' => '射手座',
            'sjis' => 'F8AF',
            'en_name' => 'Sagittarius'
          },
          {
            'unicode' => 'E64F',
            'name' => '山羊座',
            'sjis' => 'F8B0',
            'en_name' => 'Capricorn'
          },
          {
            'unicode' => 'E650',
            'name' => '水瓶座',
            'sjis' => 'F8B1',
            'en_name' => 'Aquarius'
          },
          {
            'unicode' => 'E651',
            'name' => '魚座',
            'sjis' => 'F8B2',
            'en_name' => 'Pisces'
          },
          {
            'unicode' => 'E652',
            'name' => 'スポーツ',
            'sjis' => 'F8B3',
            'en_name' => 'Sports'
          },
          {
            'unicode' => 'E653',
            'name' => '野球',
            'sjis' => 'F8B4',
            'en_name' => 'Baseball'
          },
          {
            'unicode' => 'E654',
            'name' => 'ゴルフ',
            'sjis' => 'F8B5',
            'en_name' => 'Golf'
          },
          {
            'unicode' => 'E655',
            'name' => 'テニス',
            'sjis' => 'F8B6',
            'en_name' => 'Tennis'
          },
          {
            'unicode' => 'E656',
            'name' => 'サッカー',
            'sjis' => 'F8B7',
            'en_name' => 'Soccer'
          },
          {
            'unicode' => 'E657',
            'name' => 'スキー',
            'sjis' => 'F8B8',
            'en_name' => 'Ski'
          },
          {
            'unicode' => 'E658',
            'name' => 'バスケットボール',
            'sjis' => 'F8B9',
            'en_name' => 'Basketball'
          },
          {
            'unicode' => 'E659',
            'name' => 'モータースポーツ',
            'sjis' => 'F8BA',
            'en_name' => 'Motor sports'
          },
          {
            'unicode' => 'E65A',
            'name' => 'ポケットベル',
            'sjis' => 'F8BB',
            'en_name' => 'Pager'
          },
          {
            'unicode' => 'E65B',
            'name' => '電車',
            'sjis' => 'F8BC',
            'en_name' => 'Train'
          },
          {
            'unicode' => 'E65C',
            'name' => '地下鉄',
            'sjis' => 'F8BD',
            'en_name' => 'Subway'
          },
          {
            'unicode' => 'E65D',
            'name' => '新幹線',
            'sjis' => 'F8BE',
            'en_name' => 'Bullet train'
          },
          {
            'unicode' => 'E65E',
            'name' => '車（セダン）',
            'sjis' => 'F8BF',
            'en_name' => 'Car (sedan)'
          },
          {
            'unicode' => 'E65F',
            'name' => '車（ＲＶ）',
            'sjis' => 'F8C0',
            'en_name' => 'Car (RV)'
          },
          {
            'unicode' => 'E660',
            'name' => 'バス',
            'sjis' => 'F8C1',
            'en_name' => 'Bus'
          },
          {
            'unicode' => 'E661',
            'name' => '船',
            'sjis' => 'F8C2',
            'en_name' => 'Ship'
          },
          {
            'unicode' => 'E662',
            'name' => '飛行機',
            'sjis' => 'F8C3',
            'en_name' => 'Airplane'
          },
          {
            'unicode' => 'E663',
            'name' => '家',
            'sjis' => 'F8C4',
            'en_name' => 'House'
          },
          {
            'unicode' => 'E664',
            'name' => 'ビル',
            'sjis' => 'F8C5',
            'en_name' => 'Building'
          },
          {
            'unicode' => 'E665',
            'name' => '郵便局',
            'sjis' => 'F8C6',
            'en_name' => 'Post office'
          },
          {
            'unicode' => 'E666',
            'name' => '病院',
            'sjis' => 'F8C7',
            'en_name' => 'Hospital'
          },
          {
            'unicode' => 'E667',
            'name' => '銀行',
            'sjis' => 'F8C8',
            'en_name' => 'Bank'
          },
          {
            'unicode' => 'E668',
            'name' => 'ＡＴＭ',
            'sjis' => 'F8C9',
            'en_name' => 'ATM'
          },
          {
            'unicode' => 'E669',
            'name' => 'ホテル',
            'sjis' => 'F8CA',
            'en_name' => 'Hotel'
          },
          {
            'unicode' => 'E66A',
            'name' => 'コンビニ',
            'sjis' => 'F8CB',
            'en_name' => 'Convenience store'
          },
          {
            'unicode' => 'E66B',
            'name' => 'ガソリンスタンド',
            'sjis' => 'F8CC',
            'en_name' => 'Gas station'
          },
          {
            'unicode' => 'E66C',
            'name' => '駐車場',
            'sjis' => 'F8CD',
            'en_name' => 'Parking'
          },
          {
            'unicode' => 'E66D',
            'name' => '信号',
            'sjis' => 'F8CE',
            'en_name' => 'Traffic signal'
          },
          {
            'unicode' => 'E66E',
            'name' => 'トイレ',
            'sjis' => 'F8CF',
            'en_name' => 'Toilet'
          },
          {
            'unicode' => 'E66F',
            'name' => 'レストラン',
            'sjis' => 'F8D0',
            'en_name' => 'Restaurant'
          },
          {
            'unicode' => 'E670',
            'name' => '喫茶店',
            'sjis' => 'F8D1',
            'en_name' => 'Café'
          },
          {
            'unicode' => 'E671',
            'name' => 'バー',
            'sjis' => 'F8D2',
            'en_name' => 'Bar'
          },
          {
            'unicode' => 'E672',
            'name' => 'ビール',
            'sjis' => 'F8D3',
            'en_name' => 'Beer'
          },
          {
            'unicode' => 'E673',
            'name' => 'ファーストフード',
            'sjis' => 'F8D4',
            'en_name' => 'Fast food'
          },
          {
            'unicode' => 'E674',
            'name' => 'ブティック',
            'sjis' => 'F8D5',
            'en_name' => 'Boutique'
          },
          {
            'unicode' => 'E675',
            'name' => '美容院',
            'sjis' => 'F8D6',
            'en_name' => 'Hairdresser'
          },
          {
            'unicode' => 'E676',
            'name' => 'カラオケ',
            'sjis' => 'F8D7',
            'en_name' => 'Karaoke'
          },
          {
            'unicode' => 'E677',
            'name' => '映画',
            'sjis' => 'F8D8',
            'en_name' => 'Movie'
          },
          {
            'unicode' => 'E678',
            'name' => '右斜め上',
            'sjis' => 'F8D9',
            'en_name' => 'Diagonally upward toward right'
          },
          {
            'unicode' => 'E679',
            'name' => '遊園地',
            'sjis' => 'F8DA',
            'en_name' => 'Amusement park'
          },
          {
            'unicode' => 'E67A',
            'name' => '音楽',
            'sjis' => 'F8DB',
            'en_name' => 'Music'
          },
          {
            'unicode' => 'E67B',
            'name' => 'アート',
            'sjis' => 'F8DC',
            'en_name' => 'Art'
          },
          {
            'unicode' => 'E67C',
            'name' => '演劇',
            'sjis' => 'F8DD',
            'en_name' => 'Drama'
          },
          {
            'unicode' => 'E67D',
            'name' => 'イベント',
            'sjis' => 'F8DE',
            'en_name' => 'Event'
          },
          {
            'unicode' => 'E67E',
            'name' => 'チケット',
            'sjis' => 'F8DF',
            'en_name' => 'Ticket'
          },
          {
            'unicode' => 'E67F',
            'name' => '喫煙',
            'sjis' => 'F8E0',
            'en_name' => 'Smoking'
          },
          {
            'unicode' => 'E680',
            'name' => '禁煙',
            'sjis' => 'F8E1',
            'en_name' => 'Non-smoking'
          },
          {
            'unicode' => 'E681',
            'name' => 'カメラ',
            'sjis' => 'F8E2',
            'en_name' => 'Camera'
          },
          {
            'unicode' => 'E682',
            'name' => 'カバン',
            'sjis' => 'F8E3',
            'en_name' => 'Bag'
          },
          {
            'unicode' => 'E683',
            'name' => '本',
            'sjis' => 'F8E4',
            'en_name' => 'Book'
          },
          {
            'unicode' => 'E684',
            'name' => 'リボン',
            'sjis' => 'F8E5',
            'en_name' => 'Ribbon'
          },
          {
            'unicode' => 'E685',
            'name' => 'プレゼント',
            'sjis' => 'F8E6',
            'en_name' => 'Present'
          },
          {
            'unicode' => 'E686',
            'name' => 'バースデー',
            'sjis' => 'F8E7',
            'en_name' => 'Birthday'
          },
          {
            'unicode' => 'E687',
            'name' => '電話',
            'sjis' => 'F8E8',
            'en_name' => 'Phone'
          },
          {
            'unicode' => 'E688',
            'name' => '携帯電話',
            'sjis' => 'F8E9',
            'en_name' => 'Mobile phone'
          },
          {
            'unicode' => 'E689',
            'name' => 'メモ',
            'sjis' => 'F8EA',
            'en_name' => 'Memo'
          },
          {
            'unicode' => 'E68A',
            'name' => 'ＴＶ',
            'sjis' => 'F8EB',
            'en_name' => 'TV'
          },
          {
            'unicode' => 'E68B',
            'name' => 'ゲーム',
            'sjis' => 'F8EC',
            'en_name' => 'Game'
          },
          {
            'unicode' => 'E68C',
            'name' => 'ＣＤ',
            'sjis' => 'F8ED',
            'en_name' => 'CD'
          },
          {
            'unicode' => 'E68D',
            'name' => 'ハート',
            'sjis' => 'F8EE',
            'en_name' => 'Heart'
          },
          {
            'unicode' => 'E68E',
            'name' => 'スペード',
            'sjis' => 'F8EF',
            'en_name' => 'Spade'
          },
          {
            'unicode' => 'E68F',
            'name' => 'ダイヤ',
            'sjis' => 'F8F0',
            'en_name' => 'Diamond'
          },
          {
            'unicode' => 'E690',
            'name' => 'クラブ',
            'sjis' => 'F8F1',
            'en_name' => 'Club'
          },
          {
            'unicode' => 'E691',
            'name' => '目',
            'sjis' => 'F8F2',
            'en_name' => 'Eyes'
          },
          {
            'unicode' => 'E692',
            'name' => '耳',
            'sjis' => 'F8F3',
            'en_name' => 'Ear'
          },
          {
            'unicode' => 'E693',
            'name' => '手（グー）',
            'sjis' => 'F8F4',
            'en_name' => 'Hand (rock)'
          },
          {
            'unicode' => 'E694',
            'name' => '手（チョキ）',
            'sjis' => 'F8F5',
            'en_name' => 'Hand (scissors)'
          },
          {
            'unicode' => 'E695',
            'name' => '手（パー）',
            'sjis' => 'F8F6',
            'en_name' => 'Hand (paper)'
          },
          {
            'unicode' => 'E696',
            'name' => '右斜め下',
            'sjis' => 'F8F7',
            'en_name' => 'Diagonally downward toward right'
          },
          {
            'unicode' => 'E697',
            'name' => '左斜め上',
            'sjis' => 'F8F8',
            'en_name' => 'Diagonally upward toward left'
          },
          {
            'unicode' => 'E698',
            'name' => '足',
            'sjis' => 'F8F9',
            'en_name' => 'Foot'
          },
          {
            'unicode' => 'E699',
            'name' => 'くつ',
            'sjis' => 'F8FA',
            'en_name' => 'Shoe'
          },
          {
            'unicode' => 'E69A',
            'name' => '眼鏡',
            'sjis' => 'F8FB',
            'en_name' => 'Eyeglasses'
          },
          {
            'unicode' => 'E69B',
            'name' => '車椅子',
            'sjis' => 'F8FC',
            'en_name' => 'Wheelchair'
          },
          {
            'unicode' => 'E69C',
            'name' => '新月',
            'sjis' => 'F940',
            'en_name' => 'New moon'
          },
          {
            'unicode' => 'E69D',
            'name' => 'やや欠け月',
            'sjis' => 'F941',
            'en_name' => 'Waning moon'
          },
          {
            'unicode' => 'E69E',
            'name' => '半月',
            'sjis' => 'F942',
            'en_name' => 'Half moon'
          },
          {
            'unicode' => 'E69F',
            'name' => '三日月',
            'sjis' => 'F943',
            'en_name' => 'Crescent moon'
          },
          {
            'unicode' => 'E6A0',
            'name' => '満月',
            'sjis' => 'F944',
            'en_name' => 'Full moon'
          },
          {
            'unicode' => 'E6A1',
            'name' => '犬',
            'sjis' => 'F945',
            'en_name' => 'Dog'
          },
          {
            'unicode' => 'E6A2',
            'name' => '猫',
            'sjis' => 'F946',
            'en_name' => 'Cat'
          },
          {
            'unicode' => 'E6A3',
            'name' => 'リゾート',
            'sjis' => 'F947',
            'en_name' => 'Resort'
          },
          {
            'unicode' => 'E6A4',
            'name' => 'クリスマス',
            'sjis' => 'F948',
            'en_name' => 'Christmas'
          },
          {
            'unicode' => 'E6A5',
            'name' => '左斜め下',
            'sjis' => 'F949',
            'en_name' => 'Diagonally downward toward left'
          },
          {
            'unicode' => 'E6CE',
            'name' => 'phone to',
            'sjis' => 'F972',
            'en_name' => 'Phone to'
          },
          {
            'unicode' => 'E6CF',
            'name' => 'mail to',
            'sjis' => 'F973',
            'en_name' => 'mail to'
          },
          {
            'unicode' => 'E6D0',
            'name' => 'fax to',
            'sjis' => 'F974',
            'en_name' => 'fax to'
          },
          {
            'unicode' => 'E6D1',
            'name' => 'iモード',
            'sjis' => 'F975',
            'en_name' => 'i-mode'
          },
          {
            'unicode' => 'E6D2',
            'name' => 'iモード（枠付き）',
            'sjis' => 'F976',
            'en_name' => 'i-mode with frame'
          },
          {
            'unicode' => 'E6D3',
            'name' => 'メール',
            'sjis' => 'F977',
            'en_name' => 'Mail'
          },
          {
            'unicode' => 'E6D4',
            'name' => 'ドコモ提供',
            'sjis' => 'F978',
            'en_name' => 'Provided by DoCoMo'
          },
          {
            'unicode' => 'E6D5',
            'name' => 'ドコモポイント',
            'sjis' => 'F979',
            'en_name' => 'DoCoMo point'
          },
          {
            'unicode' => 'E6D6',
            'name' => '有料',
            'sjis' => 'F97A',
            'en_name' => 'Fee charging'
          },
          {
            'unicode' => 'E6D7',
            'name' => '無料',
            'sjis' => 'F97B',
            'en_name' => 'Free of charge'
          },
          {
            'unicode' => 'E6D8',
            'name' => 'ID',
            'sjis' => 'F97C',
            'en_name' => 'ID'
          },
          {
            'unicode' => 'E6D9',
            'name' => 'パスワード',
            'sjis' => 'F97D',
            'en_name' => 'Password'
          },
          {
            'unicode' => 'E6DA',
            'name' => '次項有',
            'sjis' => 'F97E',
            'en_name' => 'Continuing'
          },
          {
            'unicode' => 'E6DB',
            'name' => 'クリア',
            'sjis' => 'F980',
            'en_name' => 'Clear'
          },
          {
            'unicode' => 'E6DC',
            'name' => 'サーチ（調べる）',
            'sjis' => 'F981',
            'en_name' => 'Search'
          },
          {
            'unicode' => 'E6DD',
            'name' => 'ＮＥＷ',
            'sjis' => 'F982',
            'en_name' => 'New'
          },
          {
            'unicode' => 'E6DE',
            'name' => '位置情報',
            'sjis' => 'F983',
            'en_name' => 'Location information'
          },
          {
            'unicode' => 'E6DF',
            'name' => 'フリーダイヤル',
            'sjis' => 'F984',
            'en_name' => 'Free dial'
          },
          {
            'unicode' => 'E6E0',
            'name' => 'シャープダイヤル',
            'sjis' => 'F985',
            'en_name' => 'Sharp dial'
          },
          {
            'unicode' => 'E6E1',
            'name' => 'モバＱ',
            'sjis' => 'F986',
            'en_name' => 'MobileQ'
          },
          {
            'unicode' => 'E6E2',
            'name' => '1',
            'sjis' => 'F987',
            'en_name' => '1'
          },
          {
            'unicode' => 'E6E3',
            'name' => '2',
            'sjis' => 'F988',
            'en_name' => '2'
          },
          {
            'unicode' => 'E6E4',
            'name' => '3',
            'sjis' => 'F989',
            'en_name' => '3'
          },
          {
            'unicode' => 'E6E5',
            'name' => '4',
            'sjis' => 'F98A',
            'en_name' => '4'
          },
          {
            'unicode' => 'E6E6',
            'name' => '5',
            'sjis' => 'F98B',
            'en_name' => '5'
          },
          {
            'unicode' => 'E6E7',
            'name' => '6',
            'sjis' => 'F98C',
            'en_name' => '6'
          },
          {
            'unicode' => 'E6E8',
            'name' => '7',
            'sjis' => 'F98D',
            'en_name' => '7'
          },
          {
            'unicode' => 'E6E9',
            'name' => '8',
            'sjis' => 'F98E',
            'en_name' => '8'
          },
          {
            'unicode' => 'E6EA',
            'name' => '9',
            'sjis' => 'F98F',
            'en_name' => '9'
          },
          {
            'unicode' => 'E6EB',
            'name' => '0',
            'sjis' => 'F990',
            'en_name' => '0'
          },
          {
            'unicode' => 'E70B',
            'name' => '決定',
            'sjis' => 'F9B0',
            'en_name' => 'Accept'
          },
          {
            'unicode' => 'E6EC',
            'name' => '黒ハート',
            'sjis' => 'F991',
            'en_name' => 'Black heart'
          },
          {
            'unicode' => 'E6ED',
            'name' => '揺れるハート',
            'sjis' => 'F992',
            'en_name' => 'Fluttering heart'
          },
          {
            'unicode' => 'E6EE',
            'name' => '失恋',
            'sjis' => 'F993',
            'en_name' => 'Heartbreak'
          },
          {
            'unicode' => 'E6EF',
            'name' => 'ハートたち（複数ハート）',
            'sjis' => 'F994',
            'en_name' => 'Hearts'
          },
          {
            'unicode' => 'E6F0',
            'name' => 'わーい（嬉しい顔）',
            'sjis' => 'F995',
            'en_name' => 'Happy face'
          },
          {
            'unicode' => 'E6F1',
            'name' => 'ちっ（怒った顔）',
            'sjis' => 'F996',
            'en_name' => 'Angry face'
          },
          {
            'unicode' => 'E6F2',
            'name' => 'がく〜（落胆した顔）',
            'sjis' => 'F997',
            'en_name' => 'Disappointed face'
          },
          {
            'unicode' => 'E6F3',
            'name' => 'もうやだ〜（悲しい顔）',
            'sjis' => 'F998',
            'en_name' => 'Sad face'
          },
          {
            'unicode' => 'E6F4',
            'name' => 'ふらふら',
            'sjis' => 'F999',
            'en_name' => 'Dizzy'
          },
          {
            'unicode' => 'E6F5',
            'name' => 'グッド（上向き矢印）',
            'sjis' => 'F99A',
            'en_name' => 'Good (upward arrow)'
          },
          {
            'unicode' => 'E6F6',
            'name' => 'るんるん',
            'sjis' => 'F99B',
            'en_name' => 'Cheerful'
          },
          {
            'unicode' => 'E6F7',
            'name' => 'いい気分（温泉）',
            'sjis' => 'F99C',
            'en_name' => 'Comfort (hot spring)'
          },
          {
            'unicode' => 'E6F8',
            'name' => 'かわいい',
            'sjis' => 'F99D',
            'en_name' => 'Cute'
          },
          {
            'unicode' => 'E6F9',
            'name' => 'キスマーク',
            'sjis' => 'F99E',
            'en_name' => 'Kiss'
          },
          {
            'unicode' => 'E6FA',
            'name' => 'ぴかぴか（新しい）',
            'sjis' => 'F99F',
            'en_name' => 'Shining new'
          },
          {
            'unicode' => 'E6FB',
            'name' => 'ひらめき',
            'sjis' => 'F9A0',
            'en_name' => 'Good idea'
          },
          {
            'unicode' => 'E6FC',
            'name' => 'むかっ（怒り）',
            'sjis' => 'F9A1',
            'en_name' => 'Angry'
          },
          {
            'unicode' => 'E6FD',
            'name' => 'パンチ',
            'sjis' => 'F9A2',
            'en_name' => 'Punch'
          },
          {
            'unicode' => 'E6FE',
            'name' => '爆弾',
            'sjis' => 'F9A3',
            'en_name' => 'Bomb'
          },
          {
            'unicode' => 'E6FF',
            'name' => 'ムード',
            'sjis' => 'F9A4',
            'en_name' => 'Mood'
          },
          {
            'unicode' => 'E700',
            'name' => 'バッド（下向き矢印）',
            'sjis' => 'F9A5',
            'en_name' => 'Bad (downward arrow)'
          },
          {
            'unicode' => 'E701',
            'name' => '眠い(睡眠)',
            'sjis' => 'F9A6',
            'en_name' => 'Sleepy (sleep)'
          },
          {
            'unicode' => 'E702',
            'name' => 'exclamation',
            'sjis' => 'F9A7',
            'en_name' => 'Exclamation mark'
          },
          {
            'unicode' => 'E703',
            'name' => 'exclamation&question',
            'sjis' => 'F9A8',
            'en_name' => 'exclamation&question marks'
          },
          {
            'unicode' => 'E704',
            'name' => 'exclamation×2',
            'sjis' => 'F9A9',
            'en_name' => 'Two exclamation marks'
          },
          {
            'unicode' => 'E705',
            'name' => 'どんっ（衝撃）',
            'sjis' => 'F9AA',
            'en_name' => 'Bump (collision)'
          },
          {
            'unicode' => 'E706',
            'name' => 'あせあせ（飛び散る汗）',
            'sjis' => 'F9AB',
            'en_name' => 'Sweat'
          },
          {
            'unicode' => 'E707',
            'name' => 'たらーっ（汗）',
            'sjis' => 'F9AC',
            'en_name' => 'Cold sweat'
          },
          {
            'unicode' => 'E708',
            'name' => 'ダッシュ（走り出すさま）',
            'sjis' => 'F9AD',
            'en_name' => 'Dash (running dash)'
          },
          {
            'unicode' => 'E709',
            'name' => 'ー（長音記号１）',
            'sjis' => 'F9AE',
            'en_name' => 'Macron 1'
          },
          {
            'unicode' => 'E70A',
            'name' => 'ー（長音記号２）',
            'sjis' => 'F9AF',
            'en_name' => 'Macron 2'
          },
          {
            'unicode' => 'E6AC',
            'name' => 'カチンコ',
            'sjis' => 'F950',
            'en_name' => 'Clapboard'
          },
          {
            'unicode' => 'E6AD',
            'name' => 'ふくろ',
            'sjis' => 'F951',
            'en_name' => 'Pouch'
          },
          {
            'unicode' => 'E6AE',
            'name' => 'ペン',
            'sjis' => 'F952',
            'en_name' => 'Pen'
          },
          {
            'unicode' => 'E6B1',
            'name' => '人影',
            'sjis' => 'F955',
            'en_name' => 'Silhouette'
          },
          {
            'unicode' => 'E6B2',
            'name' => 'いす',
            'sjis' => 'F956',
            'en_name' => 'Chair'
          },
          {
            'unicode' => 'E6B3',
            'name' => '夜',
            'sjis' => 'F957',
            'en_name' => 'Night'
          },
          {
            'unicode' => 'E6B7',
            'name' => 'soon',
            'sjis' => 'F95B',
            'en_name' => 'Soon'
          },
          {
            'unicode' => 'E6B8',
            'name' => 'on',
            'sjis' => 'F95C',
            'en_name' => 'on'
          },
          {
            'unicode' => 'E6B9',
            'name' => 'end',
            'sjis' => 'F95D',
            'en_name' => 'end'
          },
          {
            'unicode' => 'E6BA',
            'name' => '時計',
            'sjis' => 'F95E',
            'en_name' => 'Clock'
          },
          {
            'unicode' => 'E70C',
            'name' => 'iアプリ',
            'sjis' => 'F9B1',
            'en_name' => 'i-αppli'
          },
          {
            'unicode' => 'E70D',
            'name' => 'iアプリ（枠付き）',
            'sjis' => 'F9B2',
            'en_name' => 'i-αppli (with border)'
          },
          {
            'unicode' => 'E70E',
            'name' => 'Tシャツ（ボーダー）',
            'sjis' => 'F9B3',
            'en_name' => 'T-shirt (border)'
          },
          {
            'unicode' => 'E70F',
            'name' => 'がま口財布',
            'sjis' => 'F9B4',
            'en_name' => 'Purse'
          },
          {
            'unicode' => 'E710',
            'name' => '化粧',
            'sjis' => 'F9B5',
            'en_name' => 'Make-up'
          },
          {
            'unicode' => 'E711',
            'name' => 'ジーンズ',
            'sjis' => 'F9B6',
            'en_name' => 'Jeans'
          },
          {
            'unicode' => 'E712',
            'name' => 'スノボ',
            'sjis' => 'F9B7',
            'en_name' => 'Snowboarding'
          },
          {
            'unicode' => 'E713',
            'name' => 'チャペル',
            'sjis' => 'F9B8',
            'en_name' => 'Chapel'
          },
          {
            'unicode' => 'E714',
            'name' => 'ドア',
            'sjis' => 'F9B9',
            'en_name' => 'Door'
          },
          {
            'unicode' => 'E715',
            'name' => 'ドル袋',
            'sjis' => 'F9BA',
            'en_name' => 'Money bag'
          },
          {
            'unicode' => 'E716',
            'name' => 'パソコン',
            'sjis' => 'F9BB',
            'en_name' => 'Computer'
          },
          {
            'unicode' => 'E717',
            'name' => 'ラブレター',
            'sjis' => 'F9BC',
            'en_name' => 'Love letter'
          },
          {
            'unicode' => 'E718',
            'name' => 'レンチ',
            'sjis' => 'F9BD',
            'en_name' => 'Wrench'
          },
          {
            'unicode' => 'E719',
            'name' => '鉛筆',
            'sjis' => 'F9BE',
            'en_name' => 'Pencil'
          },
          {
            'unicode' => 'E71A',
            'name' => '王冠',
            'sjis' => 'F9BF',
            'en_name' => 'Crown'
          },
          {
            'unicode' => 'E71B',
            'name' => '指輪',
            'sjis' => 'F9C0',
            'en_name' => 'Ring'
          },
          {
            'unicode' => 'E71C',
            'name' => '砂時計',
            'sjis' => 'F9C1',
            'en_name' => 'Sandglass'
          },
          {
            'unicode' => 'E71D',
            'name' => '自転車',
            'sjis' => 'F9C2',
            'en_name' => 'Bicycle'
          },
          {
            'unicode' => 'E71E',
            'name' => '湯のみ',
            'sjis' => 'F9C3',
            'en_name' => 'Tea cup'
          },
          {
            'unicode' => 'E71F',
            'name' => '腕時計',
            'sjis' => 'F9C4',
            'en_name' => 'Wrist watch'
          },
          {
            'unicode' => 'E720',
            'name' => '考えてる顔',
            'sjis' => 'F9C5',
            'en_name' => 'Thinking face'
          },
          {
            'unicode' => 'E721',
            'name' => 'ほっとした顔',
            'sjis' => 'F9C6',
            'en_name' => 'Relief face'
          },
          {
            'unicode' => 'E722',
            'name' => '冷や汗',
            'sjis' => 'F9C7',
            'en_name' => 'Cold sweat'
          },
          {
            'unicode' => 'E723',
            'name' => '冷や汗2',
            'sjis' => 'F9C8',
            'en_name' => 'Cold sweat 2'
          },
          {
            'unicode' => 'E724',
            'name' => 'ぷっくっくな顔',
            'sjis' => 'F9C9',
            'en_name' => 'Pouting face'
          },
          {
            'unicode' => 'E725',
            'name' => 'ボケーっとした顔',
            'sjis' => 'F9CA',
            'en_name' => 'Expressionless face'
          },
          {
            'unicode' => 'E726',
            'name' => '目がハート',
            'sjis' => 'F9CB',
            'en_name' => 'Heart shaped eyes'
          },
          {
            'unicode' => 'E727',
            'name' => '指でOK',
            'sjis' => 'F9CC',
            'en_name' => 'Thumbs up'
          },
          {
            'unicode' => 'E728',
            'name' => 'あっかんべー',
            'sjis' => 'F9CD',
            'en_name' => 'Sticking tongue out'
          },
          {
            'unicode' => 'E729',
            'name' => 'ウィンク',
            'sjis' => 'F9CE',
            'en_name' => 'Wink'
          },
          {
            'unicode' => 'E72A',
            'name' => 'うれしい顔',
            'sjis' => 'F9CF',
            'en_name' => 'Happy face'
          },
          {
            'unicode' => 'E72B',
            'name' => 'がまん顔',
            'sjis' => 'F9D0',
            'en_name' => 'Enduring face'
          },
          {
            'unicode' => 'E72C',
            'name' => '猫2',
            'sjis' => 'F9D1',
            'en_name' => 'Cat 2'
          },
          {
            'unicode' => 'E72D',
            'name' => '泣き顔',
            'sjis' => 'F9D2',
            'en_name' => 'Crying'
          },
          {
            'unicode' => 'E72E',
            'name' => '涙',
            'sjis' => 'F9D3',
            'en_name' => 'Tear'
          },
          {
            'unicode' => 'E72F',
            'name' => 'NG',
            'sjis' => 'F9D4',
            'en_name' => 'NG (No good)'
          },
          {
            'unicode' => 'E730',
            'name' => 'クリップ',
            'sjis' => 'F9D5',
            'en_name' => 'Paper clip'
          },
          {
            'unicode' => 'E731',
            'name' => 'コピーライト',
            'sjis' => 'F9D6',
            'en_name' => 'Copyright'
          },
          {
            'unicode' => 'E732',
            'name' => 'トレードマーク',
            'sjis' => 'F9D7',
            'en_name' => 'Trademark'
          },
          {
            'unicode' => 'E733',
            'name' => '走る人',
            'sjis' => 'F9D8',
            'en_name' => 'Running man'
          },
          {
            'unicode' => 'E734',
            'name' => 'マル秘',
            'sjis' => 'F9D9',
            'en_name' => 'Top secret'
          },
          {
            'unicode' => 'E735',
            'name' => 'リサイクル',
            'sjis' => 'F9DA',
            'en_name' => 'Recycle'
          },
          {
            'unicode' => 'E736',
            'name' => 'レジスタードトレードマーク',
            'sjis' => 'F9DB',
            'en_name' => 'Registered trademark'
          },
          {
            'unicode' => 'E737',
            'name' => '危険・警告',
            'sjis' => 'F9DC',
            'en_name' => 'Danger / Caution'
          },
          {
            'unicode' => 'E738',
            'name' => '禁止',
            'sjis' => 'F9DD',
            'en_name' => 'Prohibited'
          },
          {
            'unicode' => 'E739',
            'name' => '空室・空席・空車',
            'sjis' => 'F9DE',
            'en_name' => 'Vacant'
          },
          {
            'unicode' => 'E73A',
            'name' => '合格マーク',
            'sjis' => 'F9DF',
            'en_name' => 'Approved'
          },
          {
            'unicode' => 'E73B',
            'name' => '満室・満席・満車',
            'sjis' => 'F9E0',
            'en_name' => 'Full'
          },
          {
            'unicode' => 'E73C',
            'name' => '矢印左右',
            'sjis' => 'F9E1',
            'en_name' => 'Horizontal arrows'
          },
          {
            'unicode' => 'E73D',
            'name' => '矢印上下',
            'sjis' => 'F9E2',
            'en_name' => 'Vertical arrows'
          },
          {
            'unicode' => 'E73E',
            'name' => '学校',
            'sjis' => 'F9E3',
            'en_name' => 'School'
          },
          {
            'unicode' => 'E73F',
            'name' => '波',
            'sjis' => 'F9E4',
            'en_name' => 'Wave'
          },
          {
            'unicode' => 'E740',
            'name' => '富士山',
            'sjis' => 'F9E5',
            'en_name' => 'Mount Fuji'
          },
          {
            'unicode' => 'E741',
            'name' => 'クローバー',
            'sjis' => 'F9E6',
            'en_name' => '4-leaf clover'
          },
          {
            'unicode' => 'E742',
            'name' => 'さくらんぼ',
            'sjis' => 'F9E7',
            'en_name' => 'Cherries'
          },
          {
            'unicode' => 'E743',
            'name' => 'チューリップ',
            'sjis' => 'F9E8',
            'en_name' => 'Tulip'
          },
          {
            'unicode' => 'E744',
            'name' => 'バナナ',
            'sjis' => 'F9E9',
            'en_name' => 'Banana'
          },
          {
            'unicode' => 'E745',
            'name' => 'りんご',
            'sjis' => 'F9EA',
            'en_name' => 'Apple'
          },
          {
            'unicode' => 'E746',
            'name' => '芽',
            'sjis' => 'F9EB',
            'en_name' => 'Seedling'
          },
          {
            'unicode' => 'E747',
            'name' => 'もみじ',
            'sjis' => 'F9EC',
            'en_name' => 'Maple leaf'
          },
          {
            'unicode' => 'E748',
            'name' => '桜',
            'sjis' => 'F9ED',
            'en_name' => 'Cherry blossom'
          },
          {
            'unicode' => 'E749',
            'name' => 'おにぎり',
            'sjis' => 'F9EE',
            'en_name' => 'Rice ball'
          },
          {
            'unicode' => 'E74A',
            'name' => 'ショートケーキ',
            'sjis' => 'F9EF',
            'en_name' => 'Short cake'
          },
          {
            'unicode' => 'E74B',
            'name' => 'とっくり（おちょこ付き）',
            'sjis' => 'F9F0',
            'en_name' => 'Sake bottle (sake cup)'
          },
          {
            'unicode' => 'E74C',
            'name' => 'どんぶり',
            'sjis' => 'F9F1',
            'en_name' => 'Bowl'
          },
          {
            'unicode' => 'E74D',
            'name' => 'パン',
            'sjis' => 'F9F2',
            'en_name' => 'Bread'
          },
          {
            'unicode' => 'E74E',
            'name' => 'かたつむり',
            'sjis' => 'F9F3',
            'en_name' => 'Snail'
          },
          {
            'unicode' => 'E74F',
            'name' => 'ひよこ',
            'sjis' => 'F9F4',
            'en_name' => 'Baby chick'
          },
          {
            'unicode' => 'E750',
            'name' => 'ペンギン',
            'sjis' => 'F9F5',
            'en_name' => 'Penguin'
          },
          {
            'unicode' => 'E751',
            'name' => '魚',
            'sjis' => 'F9F6',
            'en_name' => 'Fish'
          },
          {
            'unicode' => 'E752',
            'name' => 'うまい！',
            'sjis' => 'F9F7',
            'en_name' => 'Yumm!'
          },
          {
            'unicode' => 'E753',
            'name' => 'ウッシッシ',
            'sjis' => 'F9F8',
            'en_name' => 'He he he'
          },
          {
            'unicode' => 'E754',
            'name' => 'ウマ',
            'sjis' => 'F9F9',
            'en_name' => 'Horse'
          },
          {
            'unicode' => 'E755',
            'name' => 'ブタ',
            'sjis' => 'F9FA',
            'en_name' => 'Pig'
          },
          {
            'unicode' => 'E756',
            'name' => 'ワイングラス',
            'sjis' => 'F9FB',
            'en_name' => 'Wine glass'
          },
          {
            'unicode' => 'E757',
            'name' => 'げっそり',
            'sjis' => 'F9FC',
            'en_name' => 'Very thin'
          }
        ]
